"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("../../command");
const cf = require("../../utils/common-flags");
const ca = require("../../utils/common-args");
const lazy_1 = require("../../utils/lazy");
const messages_1 = require("../../utils/messages");
class AppRestartCmd extends command_1.default {
    async run() {
        const { args: params } = this.parse(AppRestartCmd);
        const { getApplication } = await Promise.resolve().then(() => require('../../utils/sdk'));
        const balena = lazy_1.getBalenaSdk();
        const application = await getApplication(balena, params.application);
        await balena.models.application.restart(application.id);
    }
}
exports.default = AppRestartCmd;
AppRestartCmd.description = lazy_1.stripIndent `
		Restart an application.

		Restart all devices belonging to an application.

		${messages_1.applicationIdInfo.split('\n').join('\n\t\t')}
	`;
AppRestartCmd.examples = [
    '$ balena app restart MyApp',
    '$ balena app restart myorg/myapp',
];
AppRestartCmd.args = [ca.applicationRequired];
AppRestartCmd.usage = 'app restart <application>';
AppRestartCmd.flags = {
    help: cf.help,
};
AppRestartCmd.authenticated = true;
//# sourceMappingURL=restart.js.map