"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("../../command");
const cf = require("../../utils/common-flags");
const lazy_1 = require("../../utils/lazy");
class ConfigInjectCmd extends command_1.default {
    async run() {
        const { args: params, flags: options } = this.parse(ConfigInjectCmd);
        const { safeUmount } = await Promise.resolve().then(() => require('../../utils/umount'));
        const drive = options.drive || (await lazy_1.getVisuals().drive('Select the device/OS drive'));
        await safeUmount(drive);
        const fs = await Promise.resolve().then(() => require('fs'));
        const configJSON = JSON.parse(await fs.promises.readFile(params.file, 'utf8'));
        const config = await Promise.resolve().then(() => require('balena-config-json'));
        await config.write(drive, options.type, configJSON);
        console.info('Done');
    }
}
exports.default = ConfigInjectCmd;
ConfigInjectCmd.description = lazy_1.stripIndent `
		Inject a configuration file into a device or OS image.

		Inject a config.json file to the mounted filesystem,
		e.g. the SD card of a provisioned device or balenaOS image.
	`;
ConfigInjectCmd.examples = [
    '$ balena config inject my/config.json --type raspberrypi3',
    '$ balena config inject my/config.json --type raspberrypi3 --drive /dev/disk2',
];
ConfigInjectCmd.args = [
    {
        name: 'file',
        description: 'the path to the config.json file to inject',
        required: true,
    },
];
ConfigInjectCmd.usage = 'config inject <file>';
ConfigInjectCmd.flags = {
    type: cf.deviceType,
    drive: cf.driveOrImg,
    help: cf.help,
};
ConfigInjectCmd.authenticated = true;
ConfigInjectCmd.root = true;
//# sourceMappingURL=inject.js.map