"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("../../command");
const cf = require("../../utils/common-flags");
const lazy_1 = require("../../utils/lazy");
class ConfigWriteCmd extends command_1.default {
    async run() {
        const { args: params, flags: options } = this.parse(ConfigWriteCmd);
        const { denyMount, safeUmount } = await Promise.resolve().then(() => require('../../utils/umount'));
        const drive = options.drive || (await lazy_1.getVisuals().drive('Select the device drive'));
        await safeUmount(drive);
        const config = await Promise.resolve().then(() => require('balena-config-json'));
        const configJSON = await config.read(drive, options.type);
        console.info(`Setting ${params.key} to ${params.value}`);
        ConfigWriteCmd.updateConfigJson(configJSON, params.key, params.value);
        await denyMount(drive, async () => {
            await safeUmount(drive);
            await config.write(drive, options.type, configJSON);
        });
        console.info('Done');
    }
    static updateConfigJson(configJSON, key, value) {
        const _ = require('lodash');
        _.setWith(configJSON, key, value, (v) => v || {});
    }
}
exports.default = ConfigWriteCmd;
ConfigWriteCmd.description = lazy_1.stripIndent `
		Write a key-value pair to configuration of a device or OS image.

		Write a key-value pair to the config.json file on the mounted filesystem,
		e.g. the SD card of a provisioned device or balenaOS image.
	`;
ConfigWriteCmd.examples = [
    '$ balena config write --type raspberrypi3 username johndoe',
    '$ balena config write --type raspberrypi3 --drive /dev/disk2 username johndoe',
    '$ balena config write --type raspberrypi3 files.network/settings "..."',
];
ConfigWriteCmd.args = [
    {
        name: 'key',
        description: 'the key of the config parameter to write',
        required: true,
    },
    {
        name: 'value',
        description: 'the value of the config parameter to write',
        required: true,
    },
];
ConfigWriteCmd.usage = 'config write <key> <value>';
ConfigWriteCmd.flags = {
    type: cf.deviceType,
    drive: cf.driveOrImg,
    help: cf.help,
};
ConfigWriteCmd.authenticated = true;
ConfigWriteCmd.root = true;
//# sourceMappingURL=write.js.map