"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const command_2 = require("../../command");
const cf = require("../../utils/common-flags");
const lazy_1 = require("../../utils/lazy");
const validation_1 = require("../../utils/validation");
class DeviceLocalModeCmd extends command_2.default {
    async run() {
        const { args: params, flags: options } = this.parse(DeviceLocalModeCmd);
        const balena = lazy_1.getBalenaSdk();
        if (options.enable) {
            await balena.models.device.enableLocalMode(params.uuid);
            console.log(`Local mode on device ${params.uuid} is now ENABLED.`);
        }
        else if (options.disable) {
            await balena.models.device.disableLocalMode(params.uuid);
            console.log(`Local mode on device ${params.uuid} is now DISABLED.`);
        }
        else if (options.status) {
            const isEnabled = await balena.models.device.isInLocalMode(params.uuid);
            console.log(isEnabled);
        }
        else {
            const isEnabled = await balena.models.device.isInLocalMode(params.uuid);
            console.log(`Local mode on device ${params.uuid} is ${isEnabled ? 'ENABLED' : 'DISABLED'}.`);
            if (isEnabled) {
                console.log('To disable, use:');
                console.log(`  balena device local-mode ${params.uuid} --disable`);
            }
            else {
                console.log('To enable, use:');
                console.log(`  balena device local-mode ${params.uuid} --enable`);
            }
        }
    }
}
exports.default = DeviceLocalModeCmd;
DeviceLocalModeCmd.description = lazy_1.stripIndent `
		Get or manage the local mode status for a device.

		Output current local mode status, or enable/disable local mode
		for specified device.
	`;
DeviceLocalModeCmd.examples = [
    '$ balena device local-mode 23c73a1',
    '$ balena device local-mode 23c73a1 --enable',
    '$ balena device local-mode 23c73a1 --disable',
    '$ balena device local-mode 23c73a1 --status',
];
DeviceLocalModeCmd.args = [
    {
        name: 'uuid',
        description: 'the uuid of the device to manage',
        parse: (dev) => validation_1.tryAsInteger(dev),
        required: true,
    },
];
DeviceLocalModeCmd.usage = 'device local-mode <uuid>';
DeviceLocalModeCmd.flags = {
    enable: command_1.flags.boolean({
        description: 'enable local mode',
        exclusive: ['disable', 'status'],
    }),
    disable: command_1.flags.boolean({
        description: 'disable local mode',
        exclusive: ['enable', 'status'],
    }),
    status: command_1.flags.boolean({
        description: 'output boolean indicating local mode status',
        exclusive: ['enable', 'disable'],
    }),
    help: cf.help,
};
DeviceLocalModeCmd.authenticated = true;
//# sourceMappingURL=local-mode.js.map